@@ -54,3 +54,8 @@ def check(token,print="true"):
      else:
        print("使えないTOKEN {token}")
      return
+
+def report(token,guild_id,channel_id,message_id,reason):
+  report = requests.post('https://discord.com/api/v9/report', json={'channel_id': channel_id,'message_id': message_id,'guild_id': guild_id,'reason': reason},headers={'authorization': token})
+  if report.status_code == 200:
+    print("通報成功")
\ No newline at end of file
